@@ -56,34 +56,34 @@ __all__ = (
     "AutoScalingGroupConfigurationTypeDef",
     "AutoScalingGroupRecommendationOptionTypeDef",
     "AutoScalingGroupRecommendationTypeDef",
-    "DescribeRecommendationExportJobsRequestTypeDef",
-    "DescribeRecommendationExportJobsResponseResponseTypeDef",
+    "DescribeRecommendationExportJobsRequestRequestTypeDef",
+    "DescribeRecommendationExportJobsResponseTypeDef",
     "EBSFilterTypeDef",
     "EBSUtilizationMetricTypeDef",
-    "ExportAutoScalingGroupRecommendationsRequestTypeDef",
-    "ExportAutoScalingGroupRecommendationsResponseResponseTypeDef",
+    "ExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
+    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
     "ExportDestinationTypeDef",
-    "ExportEBSVolumeRecommendationsRequestTypeDef",
-    "ExportEBSVolumeRecommendationsResponseResponseTypeDef",
-    "ExportEC2InstanceRecommendationsRequestTypeDef",
-    "ExportEC2InstanceRecommendationsResponseResponseTypeDef",
-    "ExportLambdaFunctionRecommendationsRequestTypeDef",
-    "ExportLambdaFunctionRecommendationsResponseResponseTypeDef",
+    "ExportEBSVolumeRecommendationsRequestRequestTypeDef",
+    "ExportEBSVolumeRecommendationsResponseTypeDef",
+    "ExportEC2InstanceRecommendationsRequestRequestTypeDef",
+    "ExportEC2InstanceRecommendationsResponseTypeDef",
+    "ExportLambdaFunctionRecommendationsRequestRequestTypeDef",
+    "ExportLambdaFunctionRecommendationsResponseTypeDef",
     "FilterTypeDef",
-    "GetAutoScalingGroupRecommendationsRequestTypeDef",
-    "GetAutoScalingGroupRecommendationsResponseResponseTypeDef",
-    "GetEBSVolumeRecommendationsRequestTypeDef",
-    "GetEBSVolumeRecommendationsResponseResponseTypeDef",
-    "GetEC2InstanceRecommendationsRequestTypeDef",
-    "GetEC2InstanceRecommendationsResponseResponseTypeDef",
-    "GetEC2RecommendationProjectedMetricsRequestTypeDef",
-    "GetEC2RecommendationProjectedMetricsResponseResponseTypeDef",
-    "GetEnrollmentStatusResponseResponseTypeDef",
-    "GetLambdaFunctionRecommendationsRequestTypeDef",
-    "GetLambdaFunctionRecommendationsResponseResponseTypeDef",
+    "GetAutoScalingGroupRecommendationsRequestRequestTypeDef",
+    "GetAutoScalingGroupRecommendationsResponseTypeDef",
+    "GetEBSVolumeRecommendationsRequestRequestTypeDef",
+    "GetEBSVolumeRecommendationsResponseTypeDef",
+    "GetEC2InstanceRecommendationsRequestRequestTypeDef",
+    "GetEC2InstanceRecommendationsResponseTypeDef",
+    "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+    "GetEC2RecommendationProjectedMetricsResponseTypeDef",
+    "GetEnrollmentStatusResponseTypeDef",
+    "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
+    "GetLambdaFunctionRecommendationsResponseTypeDef",
     "GetRecommendationErrorTypeDef",
-    "GetRecommendationSummariesRequestTypeDef",
-    "GetRecommendationSummariesResponseResponseTypeDef",
+    "GetRecommendationSummariesRequestRequestTypeDef",
+    "GetRecommendationSummariesResponseTypeDef",
     "InstanceRecommendationOptionTypeDef",
     "InstanceRecommendationTypeDef",
     "JobFilterTypeDef",
@@ -102,8 +102,8 @@ __all__ = (
     "S3DestinationConfigTypeDef",
     "S3DestinationTypeDef",
     "SummaryTypeDef",
-    "UpdateEnrollmentStatusRequestTypeDef",
-    "UpdateEnrollmentStatusResponseResponseTypeDef",
+    "UpdateEnrollmentStatusRequestRequestTypeDef",
+    "UpdateEnrollmentStatusResponseTypeDef",
     "UtilizationMetricTypeDef",
     "VolumeConfigurationTypeDef",
     "VolumeRecommendationOptionTypeDef",
@@ -148,8 +148,8 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
     total=False,
 )
 
-DescribeRecommendationExportJobsRequestTypeDef = TypedDict(
-    "DescribeRecommendationExportJobsRequestTypeDef",
+DescribeRecommendationExportJobsRequestRequestTypeDef = TypedDict(
+    "DescribeRecommendationExportJobsRequestRequestTypeDef",
     {
         "jobIds": List[str],
         "filters": List["JobFilterTypeDef"],
@@ -159,8 +159,8 @@ DescribeRecommendationExportJobsRequestTypeDef = TypedDict(
     total=False,
 )
 
-DescribeRecommendationExportJobsResponseResponseTypeDef = TypedDict(
-    "DescribeRecommendationExportJobsResponseResponseTypeDef",
+DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
+    "DescribeRecommendationExportJobsResponseTypeDef",
     {
         "recommendationExportJobs": List["RecommendationExportJobTypeDef"],
         "nextToken": str,
@@ -187,14 +187,14 @@ EBSUtilizationMetricTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredExportAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredExportAutoScalingGroupRecommendationsRequestTypeDef",
+_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
     },
 )
-_OptionalExportAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalExportAutoScalingGroupRecommendationsRequestTypeDef",
+_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "filters": List["FilterTypeDef"],
@@ -206,15 +206,15 @@ _OptionalExportAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class ExportAutoScalingGroupRecommendationsRequestTypeDef(
-    _RequiredExportAutoScalingGroupRecommendationsRequestTypeDef,
-    _OptionalExportAutoScalingGroupRecommendationsRequestTypeDef,
+class ExportAutoScalingGroupRecommendationsRequestRequestTypeDef(
+    _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
+    _OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-ExportAutoScalingGroupRecommendationsResponseResponseTypeDef = TypedDict(
-    "ExportAutoScalingGroupRecommendationsResponseResponseTypeDef",
+ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
+    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
@@ -230,14 +230,14 @@ ExportDestinationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredExportEBSVolumeRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredExportEBSVolumeRecommendationsRequestTypeDef",
+_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
     },
 )
-_OptionalExportEBSVolumeRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalExportEBSVolumeRecommendationsRequestTypeDef",
+_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "filters": List["EBSFilterTypeDef"],
@@ -249,15 +249,15 @@ _OptionalExportEBSVolumeRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class ExportEBSVolumeRecommendationsRequestTypeDef(
-    _RequiredExportEBSVolumeRecommendationsRequestTypeDef,
-    _OptionalExportEBSVolumeRecommendationsRequestTypeDef,
+class ExportEBSVolumeRecommendationsRequestRequestTypeDef(
+    _RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef,
+    _OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-ExportEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
-    "ExportEBSVolumeRecommendationsResponseResponseTypeDef",
+ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
+    "ExportEBSVolumeRecommendationsResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
@@ -265,14 +265,14 @@ ExportEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExportEC2InstanceRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredExportEC2InstanceRecommendationsRequestTypeDef",
+_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
     },
 )
-_OptionalExportEC2InstanceRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalExportEC2InstanceRecommendationsRequestTypeDef",
+_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "filters": List["FilterTypeDef"],
@@ -284,15 +284,15 @@ _OptionalExportEC2InstanceRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class ExportEC2InstanceRecommendationsRequestTypeDef(
-    _RequiredExportEC2InstanceRecommendationsRequestTypeDef,
-    _OptionalExportEC2InstanceRecommendationsRequestTypeDef,
+class ExportEC2InstanceRecommendationsRequestRequestTypeDef(
+    _RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef,
+    _OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-ExportEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
-    "ExportEC2InstanceRecommendationsResponseResponseTypeDef",
+ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
+    "ExportEC2InstanceRecommendationsResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
@@ -300,14 +300,14 @@ ExportEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExportLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredExportLambdaFunctionRecommendationsRequestTypeDef",
+_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
     },
 )
-_OptionalExportLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalExportLambdaFunctionRecommendationsRequestTypeDef",
+_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "filters": List["LambdaFunctionRecommendationFilterTypeDef"],
@@ -319,15 +319,15 @@ _OptionalExportLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class ExportLambdaFunctionRecommendationsRequestTypeDef(
-    _RequiredExportLambdaFunctionRecommendationsRequestTypeDef,
-    _OptionalExportLambdaFunctionRecommendationsRequestTypeDef,
+class ExportLambdaFunctionRecommendationsRequestRequestTypeDef(
+    _RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef,
+    _OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-ExportLambdaFunctionRecommendationsResponseResponseTypeDef = TypedDict(
-    "ExportLambdaFunctionRecommendationsResponseResponseTypeDef",
+ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
+    "ExportLambdaFunctionRecommendationsResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
@@ -344,8 +344,8 @@ FilterTypeDef = TypedDict(
     total=False,
 )
 
-GetAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
-    "GetAutoScalingGroupRecommendationsRequestTypeDef",
+GetAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "autoScalingGroupArns": List[str],
@@ -356,8 +356,8 @@ GetAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetAutoScalingGroupRecommendationsResponseResponseTypeDef = TypedDict(
-    "GetAutoScalingGroupRecommendationsResponseResponseTypeDef",
+GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
+    "GetAutoScalingGroupRecommendationsResponseTypeDef",
     {
         "nextToken": str,
         "autoScalingGroupRecommendations": List["AutoScalingGroupRecommendationTypeDef"],
@@ -366,8 +366,8 @@ GetAutoScalingGroupRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetEBSVolumeRecommendationsRequestTypeDef = TypedDict(
-    "GetEBSVolumeRecommendationsRequestTypeDef",
+GetEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetEBSVolumeRecommendationsRequestRequestTypeDef",
     {
         "volumeArns": List[str],
         "nextToken": str,
@@ -378,8 +378,8 @@ GetEBSVolumeRecommendationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
-    "GetEBSVolumeRecommendationsResponseResponseTypeDef",
+GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
+    "GetEBSVolumeRecommendationsResponseTypeDef",
     {
         "nextToken": str,
         "volumeRecommendations": List["VolumeRecommendationTypeDef"],
@@ -388,8 +388,8 @@ GetEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetEC2InstanceRecommendationsRequestTypeDef = TypedDict(
-    "GetEC2InstanceRecommendationsRequestTypeDef",
+GetEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetEC2InstanceRecommendationsRequestRequestTypeDef",
     {
         "instanceArns": List[str],
         "nextToken": str,
@@ -400,8 +400,8 @@ GetEC2InstanceRecommendationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
-    "GetEC2InstanceRecommendationsResponseResponseTypeDef",
+GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
+    "GetEC2InstanceRecommendationsResponseTypeDef",
     {
         "nextToken": str,
         "instanceRecommendations": List["InstanceRecommendationTypeDef"],
@@ -410,8 +410,8 @@ GetEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetEC2RecommendationProjectedMetricsRequestTypeDef = TypedDict(
-    "GetEC2RecommendationProjectedMetricsRequestTypeDef",
+GetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     {
         "instanceArn": str,
         "stat": MetricStatisticType,
@@ -421,16 +421,16 @@ GetEC2RecommendationProjectedMetricsRequestTypeDef = TypedDict(
     },
 )
 
-GetEC2RecommendationProjectedMetricsResponseResponseTypeDef = TypedDict(
-    "GetEC2RecommendationProjectedMetricsResponseResponseTypeDef",
+GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
+    "GetEC2RecommendationProjectedMetricsResponseTypeDef",
     {
         "recommendedOptionProjectedMetrics": List["RecommendedOptionProjectedMetricTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetEnrollmentStatusResponseResponseTypeDef = TypedDict(
-    "GetEnrollmentStatusResponseResponseTypeDef",
+GetEnrollmentStatusResponseTypeDef = TypedDict(
+    "GetEnrollmentStatusResponseTypeDef",
     {
         "status": StatusType,
         "statusReason": str,
@@ -439,8 +439,8 @@ GetEnrollmentStatusResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
-    "GetLambdaFunctionRecommendationsRequestTypeDef",
+GetLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
         "functionArns": List[str],
         "accountIds": List[str],
@@ -451,8 +451,8 @@ GetLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetLambdaFunctionRecommendationsResponseResponseTypeDef = TypedDict(
-    "GetLambdaFunctionRecommendationsResponseResponseTypeDef",
+GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
+    "GetLambdaFunctionRecommendationsResponseTypeDef",
     {
         "nextToken": str,
         "lambdaFunctionRecommendations": List["LambdaFunctionRecommendationTypeDef"],
@@ -470,8 +470,8 @@ GetRecommendationErrorTypeDef = TypedDict(
     total=False,
 )
 
-GetRecommendationSummariesRequestTypeDef = TypedDict(
-    "GetRecommendationSummariesRequestTypeDef",
+GetRecommendationSummariesRequestRequestTypeDef = TypedDict(
+    "GetRecommendationSummariesRequestRequestTypeDef",
     {
         "accountIds": List[str],
         "nextToken": str,
@@ -480,8 +480,8 @@ GetRecommendationSummariesRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetRecommendationSummariesResponseResponseTypeDef = TypedDict(
-    "GetRecommendationSummariesResponseResponseTypeDef",
+GetRecommendationSummariesResponseTypeDef = TypedDict(
+    "GetRecommendationSummariesResponseTypeDef",
     {
         "nextToken": str,
         "recommendationSummaries": List["RecommendationSummaryTypeDef"],
@@ -687,14 +687,14 @@ SummaryTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredUpdateEnrollmentStatusRequestTypeDef = TypedDict(
-    "_RequiredUpdateEnrollmentStatusRequestTypeDef",
+_RequiredUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEnrollmentStatusRequestRequestTypeDef",
     {
         "status": StatusType,
     },
 )
-_OptionalUpdateEnrollmentStatusRequestTypeDef = TypedDict(
-    "_OptionalUpdateEnrollmentStatusRequestTypeDef",
+_OptionalUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEnrollmentStatusRequestRequestTypeDef",
     {
         "includeMemberAccounts": bool,
     },
@@ -702,14 +702,15 @@ _OptionalUpdateEnrollmentStatusRequestTypeDef = TypedDict(
 )
 
 
-class UpdateEnrollmentStatusRequestTypeDef(
-    _RequiredUpdateEnrollmentStatusRequestTypeDef, _OptionalUpdateEnrollmentStatusRequestTypeDef
+class UpdateEnrollmentStatusRequestRequestTypeDef(
+    _RequiredUpdateEnrollmentStatusRequestRequestTypeDef,
+    _OptionalUpdateEnrollmentStatusRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateEnrollmentStatusResponseResponseTypeDef = TypedDict(
-    "UpdateEnrollmentStatusResponseResponseTypeDef",
+UpdateEnrollmentStatusResponseTypeDef = TypedDict(
+    "UpdateEnrollmentStatusResponseTypeDef",
     {
         "status": StatusType,
         "statusReason": str,
